Project Info
============

* Project home page: https://github.com/saxix/django-concurrency
* Issue tracker: https://github.com/saxix/django-concurrency/issues?sort
* Download: http://pypi.python.org/pypi/django-concurrency/
* Docs: http://readthedocs.org/docs/django-concurrency/en/latest/


